aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorvempo <vitaliy.emporopulo@amdocs.com>2018-01-29 15:26:59 +0200
committerAvi Gaffa <avi.gaffa@amdocs.com>2018-01-30 07:23:31 +0000
commitedd7859b25d2ec9cf910ca316f9e3ed345619131 (patch)
treee557cec5b30904c2d3ee018b7f999771a52e04c8
parentf19275991fb42792c0db209aac66acb63f731a77 (diff)
Removed MdcUtil
Validation messages are propagated to the client and should not be logged as errors. No application modules can depend on logging-core. Change-Id: I36eb2f9de195e77d5008cc69dbc7b65643fe2322 Issue-ID: SDC-875 Signed-off-by: vempo <vitaliy.emporopulo@amdocs.com>
-rw-r--r--openecomp-be/lib/openecomp-sdc-logging-lib/openecomp-sdc-logging-core/src/main/java/org/openecomp/sdc/logging/context/MdcUtil.java53
-rw-r--r--openecomp-be/lib/openecomp-sdc-validation-lib/openecomp-sdc-validation-api/pom.xml1
-rw-r--r--openecomp-be/lib/openecomp-sdc-validation-lib/openecomp-sdc-validation-api/src/main/java/org/openecomp/core/validation/types/GlobalValidationContext.java63
3 files changed, 14 insertions, 103 deletions
diff --git a/openecomp-be/lib/openecomp-sdc-logging-lib/openecomp-sdc-logging-core/src/main/java/org/openecomp/sdc/logging/context/MdcUtil.java b/openecomp-be/lib/openecomp-sdc-logging-lib/openecomp-sdc-logging-core/src/main/java/org/openecomp/sdc/logging/context/MdcUtil.java
deleted file mode 100644
index acba538113..0000000000
--- a/openecomp-be/lib/openecomp-sdc-logging-lib/openecomp-sdc-logging-core/src/main/java/org/openecomp/sdc/logging/context/MdcUtil.java
+++ /dev/null
@@ -1,53 +0,0 @@
-/*
- * Copyright © 2016-2017 European Support Limited
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.openecomp.sdc.logging.context;
-
-import org.openecomp.sdc.logging.types.LoggerConstants;
-import org.slf4j.MDC;
-
-
-public class MdcUtil {
-
- /**
- * Sets values for mdc.
- *
- * @param targetEntity the target entity
- * @param targetServiceName the target service name
- * @param errorCategory the error category
- * @param errorCode the error code
- * @param errorDescription the error description
- */
- public static void setValuesForMdc(String targetEntity, String targetServiceName,
- String errorCategory, String errorCode,
- String errorDescription) {
- MDC.put(LoggerConstants.TARGET_ENTITY, targetEntity);
- MDC.put(LoggerConstants.TARGET_SERVICE_NAME, targetServiceName);
- MDC.put(LoggerConstants.ERROR_CATEGORY, errorCategory);
- MDC.put(LoggerConstants.ERROR_CODE, errorCode);
- MDC.put(LoggerConstants.ERROR_DESCRIPTION, errorDescription);
- }
-
-
- /**
- * Init mdc.
- * @param serviceName the service name
- *
- */
- public static void initMdc(String serviceName) {
- MDC.put(LoggerConstants.SERVICE_NAME, serviceName);
- }
-}
diff --git a/openecomp-be/lib/openecomp-sdc-validation-lib/openecomp-sdc-validation-api/pom.xml b/openecomp-be/lib/openecomp-sdc-validation-lib/openecomp-sdc-validation-api/pom.xml
index 487c8be87d..cde46ff357 100644
--- a/openecomp-be/lib/openecomp-sdc-validation-lib/openecomp-sdc-validation-api/pom.xml
+++ b/openecomp-be/lib/openecomp-sdc-validation-lib/openecomp-sdc-validation-api/pom.xml
@@ -39,6 +39,7 @@
<groupId>org.openecomp.sdc</groupId>
<artifactId>openecomp-sdc-logging-core</artifactId>
<version>${project.version}</version>
+ <scope>runtime</scope>
</dependency>
<dependency>
<groupId>org.openecomp.sdc</groupId>
diff --git a/openecomp-be/lib/openecomp-sdc-validation-lib/openecomp-sdc-validation-api/src/main/java/org/openecomp/core/validation/types/GlobalValidationContext.java b/openecomp-be/lib/openecomp-sdc-validation-lib/openecomp-sdc-validation-api/src/main/java/org/openecomp/core/validation/types/GlobalValidationContext.java
index 97da6ef631..b2b901a016 100644
--- a/openecomp-be/lib/openecomp-sdc-validation-lib/openecomp-sdc-validation-api/src/main/java/org/openecomp/core/validation/types/GlobalValidationContext.java
+++ b/openecomp-be/lib/openecomp-sdc-validation-lib/openecomp-sdc-validation-api/src/main/java/org/openecomp/core/validation/types/GlobalValidationContext.java
@@ -1,21 +1,17 @@
-/*-
- * ============LICENSE_START=======================================================
- * SDC
- * ================================================================================
- * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
- * ================================================================================
+/*
+ * Copyright © 2016-2017 European Support Limited
+ *
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
+ *
* http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END=========================================================
*/
package org.openecomp.core.validation.types;
@@ -25,9 +21,6 @@ import org.openecomp.core.validation.ErrorMessageCode;
import org.openecomp.sdc.datatypes.error.ErrorLevel;
import org.openecomp.sdc.logging.api.Logger;
import org.openecomp.sdc.logging.api.LoggerFactory;
-import org.openecomp.sdc.logging.context.MdcUtil;
-import org.openecomp.sdc.logging.types.LoggerConstants;
-import org.openecomp.sdc.logging.types.LoggerErrorCode;
import java.io.InputStream;
import java.util.Collection;
@@ -39,9 +32,9 @@ import java.util.stream.Collectors;
public class GlobalValidationContext {
- private static Logger logger = (Logger) LoggerFactory.getLogger(GlobalValidationContext.class);
- private Map<String, FileValidationContext> fileContextMap = new HashMap<>();
- private Map<String, MessageContainer> messageContainerMap = new HashMap<>();
+ private static final Logger LOGGER = LoggerFactory.getLogger(GlobalValidationContext.class);
+ private final Map<String, FileValidationContext> fileContextMap = new HashMap<>();
+ private final Map<String, MessageContainer> messageContainerMap = new HashMap<>();
private ErrorMessageCode messageCode;
public ErrorMessageCode getMessageCode() {
@@ -59,28 +52,21 @@ public class GlobalValidationContext {
* @param fileName the file name
* @param level the level
* @param message the message
* @param targetServiceName the target service name
* @param errorDescription the error details
*/
public void addMessage(String fileName, ErrorLevel level, String message,
- String targetServiceName, String errorDescription) {
+ String targetService, String description) {
- printLog(fileName, message, level, targetServiceName, errorDescription);
+ LOGGER.debug("{}: {} [{}]. Target: {}. Description: {}", fileName, message, level, targetService, description);
if (fileContextMap.containsKey(fileName)) {
fileContextMap.get(fileName).getMessageContainer().getMessageBuilder()
.setMessage(level.toString() + ": " + message).setLevel(level).create();
} else {
-// if (CommonMethods.isEmpty(fileName)) {
-// fileName = SdcCommon.UPLOAD_FILE;
-// }
MessageContainer messageContainer;
synchronized (this) {
- messageContainer = messageContainerMap.get(fileName);
- if (messageContainer == null) {
- messageContainer = new MessageContainer();
- messageContainerMap.put(fileName, messageContainer);
- }
+ messageContainer = messageContainerMap.computeIfAbsent(fileName, k -> new MessageContainer());
}
messageContainer.getMessageBuilder().setMessage(level.toString() + ": " + message)
.setLevel(level).create();
@@ -128,29 +114,6 @@ public class GlobalValidationContext {
return fileContextMap;
}
- private void printLog(String fileName, String message, ErrorLevel level, String targetServiceName,
- String errorDescription) {
-
- String messageToPrint = message + " in file[" + fileName + "]";
- MdcUtil.setValuesForMdc(LoggerConstants.TARGET_ENTITY_API, targetServiceName, level.name(),
- LoggerErrorCode.DATA_ERROR.getErrorCode(), errorDescription);
-
- switch (level) {
- case ERROR:
- logger.error(messageToPrint);
- break;
- case WARNING:
- logger.warn(messageToPrint);
- break;
- case INFO:
- logger.info(messageToPrint);
- break;
- default:
- break;
- }
- }
-
-
public Collection<String> files(BiPredicate<String, GlobalValidationContext> func) {
return fileContextMap.keySet().stream().filter(t -> func.test(t, this))
.collect(Collectors.toList());
@@ -59,28 +52,21 @@ public class GlobalValidationContext {
* @param level the level
* @param message the message
- * @param targetServiceName the target service name
- * @param errorDescription the error details
+ * @param targetService the target service name
+ * @param description validation event details
*/
public void addMessage(String fileName, ErrorLevel level, String message,